==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/hsb-DE.pl <==
{
  am_pm_abbreviated => [
    "dopo\N{U+0142}dnja",
    "popo\N{U+0142}dnju",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, H:mm 'hod\N{U+017a}'.",
    EHms => "E, HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d.M.y GGGGG",
    H => "H 'hod\N{U+017a}'.",
    Hm => "H:mm 'hod\N{U+017a}'.",
    Hms => "H:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmv => "H:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    "MMMMW-count-few" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
    "MMMMW-count-one" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
    "MMMMW-count-other" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
    "MMMMW-count-two" => "'tyd\N{U+017a}e\N{U+0144}' W MMMM",
    MMMMd => "d MMMM",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
    "yw-count-one" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
    "yw-count-other" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
    "yw-count-two" => "'tyd\N{U+017a}e\N{U+0144}' w 'l\N{U+011b}ta' Y",
  },
  code => "hsb-DE",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d.M.y",
  date_format_short => "d.M.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "p\N{U+00f3}n",
    "wut",
    "srj",
    "\N{U+0161}tw",
    "pja",
    "sob",
    "nje",
  ],
  day_format_narrow => [
    "p",
    "w",
    "s",
    "\N{U+0161}",
    "p",
    "s",
    "n",
  ],
  day_format_wide => [
    "p\N{U+00f3}nd\N{U+017a}ela",
    "wutora",
    "srjeda",
    "\N{U+0161}tw\N{U+00f3}rtk",
    "pjatk",
    "sobota",
    "njed\N{U+017a}ela",
  ],
  day_stand_alone_abbreviated => [
    "p\N{U+00f3}n",
    "wut",
    "srj",
    "\N{U+0161}tw",
    "pja",
    "sob",
    "nje",
  ],
  day_stand_alone_narrow => [
    "p",
    "w",
    "s",
    "\N{U+0161}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "p\N{U+00f3}nd\N{U+017a}ela",
    "wutora",
    "srjeda",
    "\N{U+0161}tw\N{U+00f3}rtk",
    "pjatk",
    "sobota",
    "njed\N{U+017a}ela",
  ],
  era_abbreviated => [
    "p\N{U+0159}.Chr.n.",
    "po Chr.n.",
  ],
  era_narrow => [
    "p\N{U+0159}.Chr.n.",
    "po Chr.n.",
  ],
  era_wide => [
    "p\N{U+0159}ed Chrystowym narod\N{U+017a}enjom",
    "po Chrystowym narod\N{U+017a}enju",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Upper Sorbian",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "m\N{U+011b}r.",
    "apr.",
    "mej.",
    "jun.",
    "jul.",
    "awg.",
    "sep.",
    "okt.",
    "now.",
    "dec.",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januara",
    "februara",
    "m\N{U+011b}rca",
    "apryla",
    "meje",
    "junija",
    "julija",
    "awgusta",
    "septembra",
    "oktobra",
    "nowembra",
    "decembra",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "m\N{U+011b}r",
    "apr",
    "mej",
    "jun",
    "jul",
    "awg",
    "sep",
    "okt",
    "now",
    "dec",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "m\N{U+011b}rc",
    "apryl",
    "meja",
    "junij",
    "julij",
    "awgust",
    "september",
    "oktober",
    "nowember",
    "december",
  ],
  name => "Upper Sorbian Germany",
  native_language => "hornjoserb\N{U+0161}\N{U+0107}ina",
  native_name => "hornjoserb\N{U+0161}\N{U+0107}ina N\N{U+011b}mska",
  native_script => undef,
  native_territory => "N\N{U+011b}mska",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. kwartal",
    "2. kwartal",
    "3. kwartal",
    "4. kwartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. kwartal",
    "2. kwartal",
    "3. kwartal",
    "4. kwartal",
  ],
  script => undef,
  territory => "Germany",
  time_format_full => "H:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm 'hod\N{U+017a}'.",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/hsb-DE.pl <==
{
  am_pm_abbreviated => [
    "dop.",
    "pop.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, H:mm 'hod\N{U+017a}'.",
    EHms => "E, HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d.M.y GGGGG",
    H => "H 'hod\N{U+017a}'.",
    Hm => "H:mm 'hod\N{U+017a}'.",
    Hms => "H:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmv => "H:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    "MMMMW-count-few" => "W. 'tyd\N{U+017a}e\N{U+0144}' MMMM",
    "MMMMW-count-one" => "W. 'tyd\N{U+017a}e\N{U+0144}' MMMM",
    "MMMMW-count-other" => "W. 'tyd\N{U+017a}e\N{U+0144}' MMMM",
    "MMMMW-count-two" => "W. 'tyd\N{U+017a}e\N{U+0144}' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d.",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "w. 'tyd\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
    "yw-count-one" => "w. 'tyd\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
    "yw-count-other" => "w. 'tyd\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
    "yw-count-two" => "w. 'tyd\N{U+017a}e\N{U+0144}' 'l\N{U+011b}ta' Y",
  },
  code => "hsb-DE",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d.M.y",
  date_format_short => "d.M.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "p\N{U+00f3}n",
    "wut",
    "srj",
    "\N{U+0161}tw",
    "pja",
    "sob",
    "nje",
  ],
  day_format_narrow => [
    "p",
    "w",
    "s",
    "\N{U+0161}",
    "p",
    "s",
    "n",
  ],
  day_format_wide => [
    "p\N{U+00f3}nd\N{U+017a}ela",
    "wutora",
    "srjeda",
    "\N{U+0161}tw\N{U+00f3}rtk",
    "pjatk",
    "sobota",
    "njed\N{U+017a}ela",
  ],
  day_stand_alone_abbreviated => [
    "p\N{U+00f3}n",
    "wut",
    "srj",
    "\N{U+0161}tw",
    "pja",
    "sob",
    "nje",
  ],
  day_stand_alone_narrow => [
    "p",
    "w",
    "s",
    "\N{U+0161}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "p\N{U+00f3}nd\N{U+017a}ela",
    "wutora",
    "srjeda",
    "\N{U+0161}tw\N{U+00f3}rtk",
    "pjatk",
    "sobota",
    "njed\N{U+017a}ela",
  ],
  era_abbreviated => [
    "p\N{U+0159}.Chr.n.",
    "po Chr.n.",
  ],
  era_narrow => [
    "p\N{U+0159}.Chr.n.",
    "po Chr.n.",
  ],
  era_wide => [
    "p\N{U+0159}ed Chrystowym narod\N{U+017a}enjom",
    "po Chrystowym narod\N{U+017a}enju",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Upper Sorbian",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "m\N{U+011b}r.",
    "apr.",
    "mej.",
    "jun.",
    "jul.",
    "awg.",
    "sep.",
    "okt.",
    "now.",
    "dec.",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januara",
    "februara",
    "m\N{U+011b}rca",
    "apryla",
    "meje",
    "junija",
    "julija",
    "awgusta",
    "septembra",
    "oktobra",
    "nowembra",
    "decembra",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "m\N{U+011b}r",
    "apr",
    "mej",
    "jun",
    "jul",
    "awg",
    "sep",
    "okt",
    "now",
    "dec",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "m\N{U+011b}rc",
    "apryl",
    "meja",
    "junij",
    "julij",
    "awgust",
    "september",
    "oktober",
    "nowember",
    "december",
  ],
  name => "Upper Sorbian Germany",
  native_language => "hornjoserb\N{U+0161}\N{U+0107}ina",
  native_name => "hornjoserb\N{U+0161}\N{U+0107}ina N\N{U+011b}mska",
  native_script => undef,
  native_territory => "N\N{U+011b}mska",
  native_variant => undef,
  quarter_format_abbreviated => [
    "kw1",
    "kw2",
    "kw3",
    "kw4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. kwartal",
    "2. kwartal",
    "3. kwartal",
    "4. kwartal",
  ],
  quarter_stand_alone_abbreviated => [
    "kw1",
    "kw2",
    "kw3",
    "kw4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. kwartal",
    "2. kwartal",
    "3. kwartal",
    "4. kwartal",
  ],
  script => undef,
  territory => "Germany",
  time_format_full => "H:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm 'hod\N{U+017a}'.",
  variant => undef,
  version => "44.1",
}
